API Reference
=============

.. autosummary::
   :toctree: _autosummary
   :recursive:

   entelecheia

main
----
.. autofunction:: entelecheia.__cli__.main

get_version
-----------
.. autofunction:: entelecheia.__init__.get_version
